// File: ConcurrentServer.java
// This is a concurrent echo server.

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.Socket;
import java.net.ServerSocket;

public class ConcurrentServer implements Runnable {
  private Socket client;
  private Thread theThread;
  private static int count;
  private static ThreadGroup threadGroup;

  public ConcurrentServer(Socket s) {
    client = s;
    theThread = new Thread(threadGroup, this, "Socket" + count);
    System.out.println("Client connected to server: " + count +
      ",  Current active threads: " + threadGroup.activeCount());
    count++;
    theThread.start();
  }
  public void run(){
    BufferedReader sockin = null;
    PrintWriter sockout = null;
    try {
      sockin = new BufferedReader(
        new InputStreamReader(client.getInputStream()));
      sockout = new PrintWriter(client.getOutputStream(), true);

      // loop, reading input from the socket and writing
      // the data to the client socket until client closes socket
      String linein = null;
      while((linein = sockin.readLine()) != null) {
        sockout.println(linein);
      }
    } catch (IOException e) {
      System.err.println(e);
    } finally {
      try {
        if (client != null) {
          client.close();
        }
      } catch (IOException e) {
        System.err.println(e);
      }
    }
  }
  public static void main(String[] args) {
    threadGroup = new ThreadGroup("Sockets");
    try {
      ServerSocket ss = new ServerSocket(7777);

      while( true ) {
        Socket s = ss.accept();
        new ConcurrentServer(s);
      }
    } catch (IOException e) {
      System.err.println(e);
    }
  }
}
