if [ -z "${ORACLE_HOME}" ] || [ -z "${ORACLE_SID}" ]
then
  echo "Your environment is not set up for Oracle."
  echo "If you want to use Oracle on this host,"
  echo "make sure Oracle is installed, and make sure"
  echo "you set ORACLE_HOME and ORACLE_SID correctly."
  echo
  echo "If you are accessing Oracle on another host, ignore this message."
  echo
  exit 1
fi

if [ $# -eq 1 ]
then
  LOGNAME=$1
elif [ -z "${LOGNAME}" -a -n "${USER}" ]
then
  LOGNAME=${USER}
  export LOGNAME
fi

while [ -z "${LOGNAME}" ]
do
  echo "Enter the username you want to use for Oracle."
  echo "An Oracle account with this name will be created for you:"
  read LOGNAME
done

echo "Creating Oracle account ${LOGNAME}/${LOGNAME}."

sqlplus system/manager <<EoF 1>&2
DROP USER ${LOGNAME} CASCADE
/
CREATE USER ${LOGNAME}
       IDENTIFIED BY ${LOGNAME}
       DEFAULT TABLESPACE oraclass
       TEMPORARY TABLESPACE temp
       QUOTA 500K ON oraclass
/
GRANT connect, resource, create trigger, create procedure
      TO ${LOGNAME}
/
COMMIT
/
exit
EoF

if [ -f emps.oracle.sql ]
then
  echo "Loading tables..."
  sqlplus ${LOGNAME}/${LOGNAME} @emps.oracle.sql 1>&2
fi

