DROP TABLE employee CASCADE CONSTRAINTS;

DROP TABLE department CASCADE CONSTRAINTS;

DROP TABLE star CASCADE CONSTRAINTS;

CREATE TABLE department
(
  department_code CHAR(2) PRIMARY KEY,
  department_name VARCHAR2(30),
  manager_id      NUMBER(8),
  city            VARCHAR2(25),
  state           CHAR(2)
);

CREATE TABLE employee
(
  id              NUMBER(8) PRIMARY KEY,
  firstname       VARCHAR2(15),
  lastname        VARCHAR2(25),
  title           VARCHAR2(30),
  department_code CHAR(2) REFERENCES department (department_code),
  supervisor_id   NUMBER(8),
  hire_date       DATE,
  salary          NUMBER(9,2)
);

CREATE TABLE star
(
  name		  VARCHAR2(15) PRIMARY KEY,
  con		  CHAR(3),
  vmag		  NUMBER(8,2),
  distance	  NUMBER(8,2),
  ra		  CHAR(12),
  dec		  CHAR(9)
);

CREATE OR REPLACE PACKAGE emp AS
  TYPE dept_rectype IS RECORD
  (
    firstname employee.firstname%TYPE,
    lastname employee.firstname%TYPE,
    department_code department.department_code%TYPE,
    department_name department.department_name%TYPE
  );

  TYPE dept_curreftype IS REF CURSOR RETURN dept_rectype;
  PROCEDURE assignDeptHead (dept IN CHAR, mgrid IN NUMBER);
  PROCEDURE getDeptHead (dept IN CHAR, mgrid OUT NUMBER);
  PROCEDURE listDeptHeads (dept_curref IN OUT dept_curreftype);

END emp;
/

CREATE OR REPLACE PACKAGE BODY emp AS
  PROCEDURE assignDeptHead (dept IN CHAR, mgrid IN NUMBER)
  IS
  BEGIN
    UPDATE employee
       SET department_code = dept
     WHERE id = mgrid;
  
    IF SQLCODE = 0 THEN
      UPDATE department
         SET manager_id = mgrid
       WHERE department_code = dept;
  
      IF SQLCODE <> 0 THEN
        ROLLBACK;
      ELSE
        COMMIT;
      END IF;
    END IF;
  END;
  
  PROCEDURE getDeptHead (dept IN CHAR, mgrid OUT NUMBER)
  IS
  BEGIN
    SELECT manager_id
      INTO mgrid
      FROM department
     WHERE department_code = dept;
  END;

  PROCEDURE listDeptHeads (dept_curref IN OUT dept_curreftype)
  IS
  BEGIN
    OPEN dept_curref FOR
      SELECT e.firstname,
             e.lastname,
             d.department_code,
             d.department_name
        FROM employee e, department d
       WHERE e.id = d.manager_id;
  END;

END emp;
/

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('SM', 'Sales and Marketing', 'Denver', 'CO');

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('RD', 'Research and Development', 'Houston', 'TX');

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('CS', 'Customer Service and Support', 'Houston', 'TX');

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('HR', 'Human Resources', 'Tucson', 'AZ');

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('SH', 'Shipping', 'Commerce City', 'CO');

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('AC', 'Accounting', 'Tucson', 'AZ');

INSERT INTO department (department_code, department_name, city, state)
            VALUES ('AD', 'Administration', 'Tucson', 'AZ');

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6567, 'Mike', 'Hodges', 'Department Manager',
                       'SM', NULL, '04-FEB-90', 64000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6644, 'Geri', 'Singh', 'Account Manager',
                       'SM', 6567, '12-MAR-91', 42000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6659, 'Sue', 'Hartman', 'Account Manager',
                       'SM', 6567, '16-OCT-89', 50000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6668, 'John', 'Jean', 'Account Manager',
                       'SM', 6567, '07-JAN-90', 40000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6863, 'Bob', 'Taylor', 'Account Manager',
                       'SM', 6567, '05-JUL-97', 49000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6892, 'Robert', 'Zehr', 'Manager',
                       'SM', 6567, '15-JUN-95', 41000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7218, 'Tom', 'Mundt', 'Sales Assistant',
                       'SM', 6892, '14-JAN-93', 45000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7285, 'Michael', 'Ann', 'Account Manager',
                       'SM', 6892, '18-JAN-88', 48000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7407, 'Allan', 'Schicker', 'Account Manager',
                       'SM', 6892, '06-MAY-88', 42000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7366, 'John', 'Cummiskey', 'Account Manager',
                       'SM', 6892, '26-APR-97', 50000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8099, 'Mark', 'Sallee', 'Account Manager',
                       'SM', 6892, '01-JAN-88', 41000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8084, 'Leigh', 'Scherer', 'Manager',
                       'SM', 6892, '22-FEB-89', 50000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8080, 'Jon', 'Scholz', 'Sales Assistant',
                       'SM', 8084, '07-JAN-93', 49000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8053, 'Valerie', 'Smith', 'Department Manager',
                       'HR', NULL, '05-DEC-91', 63000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7966, 'Barbara', 'Walker', 'Recruiter',
                       'HR', 8053, '20-DEC-95', 40000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7846, 'Anthony', 'Goffi', 'Recruiter',
                       'HR', 8053, '15-JUN-91', 52000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7644, 'Cliff', 'Absher', 'Human Resource Specialist',
                       'HR', 8053, '13-MAR-94', 47000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7502, 'Cris', 'Hunsaker', 'Department Manager',
                       'SH', NULL, '16-JUL-97', 72000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8107, 'Bonnie', 'Roth', 'Clerk',
                       'SH', 7502, '21-JUL-90', 52000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7445, 'Julie', 'Sussenbach', 'Clerk',
                       'SH', 7502, '20-AUG-91', 40000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7223, 'Glen', 'Paul', 'Department Manager',
                       'AC', NULL, '24-JAN-93', 70000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 7088, 'Dave', 'McKillip', 'Bookkeeper',
                       'AC', 7223, '19-APR-89', 44000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6881, 'Susan', 'Langley', 'Department Manager',
                       'AD', NULL, '06-MAR-96', 65000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6810, 'Michael', 'Farrelly', 'Office Manager',
                       'AD', 6881, '17-JUN-93', 47000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6783, 'Chakradhar', 'Adair', 'Office Manager',
                       'AD', 6881, '01-MAR-90', 53000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 6650, 'Terry', 'Slickers', 'Receptionist',
                       'AD', 6881, '16-MAR-93', 46000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8222, 'Robert', 'Moore', 'Assistant',
                       'AD', 6881, '13-JUL-92', 45000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8269, 'Channing', 'Martin', 'Manager',
                       'AD', 6881, '20-JUN-88', 40000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8339, 'Jack', 'Kent', 'Department Manager',
                       'CS', NULL, '19-DEC-95', 76000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8373, 'Thomas', 'Jacoby', 'Customer Service Rep',
                       'CS', 8339, '22-MAY-94', 48000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8511, 'Darcy', 'Drera', 'Customer Service Rep',
                       'CS', 8339, '07-JUN-94', 49000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8578, 'Jim', 'Cheffy', 'Customer Service Rep',
                       'CS', 8339, '07-JAN-95', 48000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8741, 'Ashraf', 'Kindvall', 'Customer Service Rep',
                       'CS', 8339, '23-JUN-92', 51000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8795, 'Lisa', 'Stewart', 'Manager',
                       'CS', 8339, '01-FEB-93', 49000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8804, 'James', 'Gaughan', 'Customer Service Rep',
                       'CS', 8795, '11-JUN-89', 47000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8798, 'Philip', 'Osen', 'Customer Service Rep',
                       'CS', 8795, '01-APR-90', 43000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9318, 'Kelly', 'Tatman', 'Customer Service Rep',
                       'CS', 8795, '20-JAN-97', 50000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9188, 'Gail', 'Ortlieb', 'Department Manager',
                       'RD', NULL, '18-MAY-89', 66000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9018, 'Dick', 'Lillrose', 'QA',
                       'RD', 9188, '19-JAN-90', 44000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8981, 'Joseph', 'Paris', 'Engineer',
                       'RD', 9188, '12-AUG-96', 47000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8785, 'Lauretta', 'Abedzadeh', 'QA',
                       'RD', 9188, '28-MAR-88', 54000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8674, 'Sue', 'Ahl', 'Engineer',
                       'RD', 9188, '24-JUL-92', 42000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8571, 'Howie', 'Ciurej', 'Manager',
                       'RD', 9188, '11-DEC-96', 51000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 8478, 'Tony', 'Filipowicz', 'Developer',
                       'RD', 8571, '23-FEB-94', 53000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9894, 'Gloria', 'Harbert', 'Engineer',
                       'RD', 8571, '27-NOV-89', 50000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9883, 'Warren', 'Carson', 'Developer',
                       'RD', 8571, '08-JAN-92', 49000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9779, 'Eleanor', 'Hill', 'QA',
                       'RD', 8571, '15-JAN-93', 44000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9765, 'Dave', 'Marsh', 'Developer',
                       'RD', 8571, '25-NOV-89', 51000.00);

INSERT INTO employee ( id, firstname, lastname, title,
                       department_code, supervisor_id, hire_date, salary)
            VALUES   ( 9683, 'Robert', 'Miller', 'Manager',
                       'RD', 8571, '27-NOV-95', 40000.00);

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Sirius', 'Cma', -1.46, 8.6, '06 45 08.9', '-16 42 58');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Canopus', 'Car', -0.72, 312.6, '06 23 57.1', '-52 41 45');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Arcturus', 'Boo', -0.04, 36.7, '14 15 39.7', '+19 10 57');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Rigil Kentaurus', 'Cen', -0.01, 4.4, '14 39 35.9', '-60 50 07');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Vega', 'Lyr', 0.03, 25.3, '18 36 56.3', '+38 47 01');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Capella', 'Aur', 0.08, 42.2, '05 16 41.4', '+45 59 53');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Rigel', 'Ori', 0.12, 772.5, '05 14 32.3', '-08 12 06');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Procion', 'Cmi', 0.38, 11.4, '07 39 18.1', '+05 13 30');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Achernar', 'Eri', 0.46, 143.7, '01 37 42.9', '-57 14 12');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Betelgeuse', 'Ori', 0.5, 427.3, '05 55 10.3', '+07 24 25');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Hadar', 'Cen', 0.61, 525.0, '14 03 49.4', '-60 22 23');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Altair', 'Aql', 0.77, 16.8, '19 50 47.0', '+08 52 06');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Aldebaran', 'Tau', 0.85, 65.1, '04 35 55.2', '+16 30 33');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Antares', 'Sco', 0.96, 603.7, '16 29 24.4', '-26 25 55');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Spica', 'Vir', 0.98, 262.1, '13 25 11.6', '-11 09 41');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Pollux', 'Gem', 1.14, 33.7, '07 45 18.9', '+28 01 34');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Fomalhaut', 'PsA', 1.16, 25.1, '22 57 39.1', '-29 37 20');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Mimosa', 'Cru', 1.25, 352.4, '12 47 43.2', '-59 41 19');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Deneb', 'Cyg', 1.25, 3227.7, '20 41 25.9', '+45 16 49');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Acrux', 'Cru', 1.33, 320.6, '12 26 35.9', '-63 05 57');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Regulus', 'Leo', 1.35, 77.5, '10 08 22.3', '+11 58 02');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Adhara', 'Cma', 1.5, 430.6, '06 58 37.5', '-28 58 20');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Gacrux', 'Cru', 1.63, 87.9, '12 31 09.9', '-57 06 48');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Shaula', 'Sco', 1.63, 702.6, '17 33 36.5', '-37 06 14');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Bellatrix', 'Ori', 1.64, 242.9, '05 25 07.9', '+06 20 59');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('El Nath', 'Tau', 1.65, 131.0, '05 26 17.5', '+28 36 27');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Miaplacidus', 'Car', 1.68, 111.1, '09 13 12.0', '-69 43 02');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Alnilan', 'Ori', 1.7, 1341.6, '05 36 12.8', '-01 12 07');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Al Na'ir', 'Gru', 1.74, 101.4, '22 08 14.0', '-46 57 40');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Alioth', 'Uma', 1.77, 80.9, '12 54 01.7', '+55 57 35');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Gama2', 'Vel', 1.78, 840.2, '08 09 32.0', '-47 20 12');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Mirfak', 'Per', 1.79, 591.7, '03 24 19.4', '+49 51 40');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Dubhe', 'Uma', 1.79, 123.6, '11 03 43.7', '+61 45 03');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Wezen', 'Cma', 1.84, 1791.2, '07 08 23.5', '-26 23 36');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Kaus Australis', 'Sgr', 1.85, 144.6, '18 24 10.3', '-34 23 05');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Avior', 'Car', 1.86, 631.8, '08 22 30.8', '-59 30 35');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Alkaid', 'Uma', 1.86, 100.6, '13 47 32.4', '+49 18 48');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Sargas', 'Sco', 1.87, 271.9, '17 37 19.2', '-42 59 52');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Menkaliman', 'Aur', 1.9, 82.1, '05 59 31.7', '+44 56 51');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Atria', 'TrA', 1.92, 415.3, '16 48 39.9', '-69 01 40');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Alhena', 'Gem', 1.93, 104.8, '06 37 42.7', '+16 23 57');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Peacock', 'Pav', 1.94, 183.1, '20 25 38.9', '-56 44 06');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Delta', 'Vel', 1.96, 79.7, '08 44 42.2', '-54 42 30');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Mirzam', 'Cma', 1.98, 499.2, '06 22 42.0', '-17 57 21');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Castor', 'Gem', 1.98, 51.5, '07 34 36.0', '+31 53 18');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Alphard', 'Hya', 1.98, 177.2, '09 27 35.2', '-08 39 31');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Hamal', 'Ari', 2.0, 65.9, '02 07 10.4', '+23 27 45');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Polaris', 'Umi', 2.02, 431.2, '02 31 48.7', '+89 15 51');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Nunki', 'Sgr', 2.02, 224.2, '18 55 15.9', '-26 17 48');

INSERT INTO star (name, con, vmag, distance, ra, dec)
            VALUES ('Deneb Kaitos', 'Cet', 2.04, 95.8, '00 43 35.2', '+52 59 12');

exit
