// File: AreaCodeLister2.java

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.TreeMap;
import java.util.StringTokenizer;

public class AreaCodeLister2 {
  private Map<String,String> areaCodes;
  private Map<String,String> abbreviations;

  public AreaCodeLister2() {
    populateAreaCodes();
    populateAbbreviations();
    printAreaCodes();
  }
  private void populateAreaCodes() {
    // change to TreeMap to have sorted results
    areaCodes = new TreeMap<String,String>();
    try {
      BufferedReader in =
        new BufferedReader(new FileReader("areacodes.txt"));

      String line = null;
      while ((line = in.readLine()) != null) {

        StringTokenizer st = new StringTokenizer(line, "\t");

        if (st.hasMoreTokens()) {
          String code = st.nextToken();
          if (st.hasMoreTokens()) {
            String abbrv = st.nextToken();
            areaCodes.put(code, abbrv);
          }
        }
      }
      in.close();
    } catch (IOException e) {
      System.err.println(e);
      System.exit(1);
    }
  }
  private void populateAbbreviations() {
    abbreviations = new HashMap<String,String>();
    try {
      BufferedReader in =
        new BufferedReader(new FileReader("abbreviations.txt"));

      String line = null;
      while ((line = in.readLine()) != null) {

        StringTokenizer st = new StringTokenizer(line, "\t");

        if (st.hasMoreTokens()) {
          String state = st.nextToken();
          if (st.hasMoreTokens()) {
            String abbrv = st.nextToken();
            abbreviations.put(abbrv, state);
          }
        }
      }
      in.close();
    } catch (IOException e) {
      System.err.println(e);
      System.exit(1);
    }
  }
  private void printAreaCodes() {
    Iterator<String> codes = areaCodes.keySet().iterator();
    Iterator<String> abbrvs = abbreviations.keySet().iterator();

    while (codes.hasNext()) {
      String code = codes.next();
      String abbrv = areaCodes.get(code);
      String state = abbreviations.get(abbrv);
      System.out.println(code + " " + state);
    }
  }
  public static void main(String[] args) {
    AreaCodeLister2 lister = new AreaCodeLister2();
  }
}
